==> haskell-quickcheck-io-0.2.0-4-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-DGgxP10rQS5DEjc4UQAWme
key: quickcheck-io-0.2.0-DGgxP10rQS5DEjc4UQAWme
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
abi: 2f4f61f5db6563abdb2c8640236753f0
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-DGgxP10rQS5DEjc4UQAWme
depends:
    QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3 base-4.10.0.0
abi-depends: QuickCheck-2.10.0.1-DTIBC3CyU6p3h4xSnOjkg1=a7db3f23c59a223edad851ccf90de895
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=403e14f0201c382f502c00d4ca640d0c
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-io-0.2.0-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-io.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-io
version: 0.2.0
id: quickcheck-io-0.2.0-1Jyoobgydpi1ixfo6rI3UE
key: quickcheck-io-0.2.0-1Jyoobgydpi1ixfo6rI3UE
license: MIT
copyright: (c) 2013-2017 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/quickcheck-io#readme
synopsis: Use HUnit assertions as QuickCheck properties
description:
    This package provides an orphan instance that allows you to
    use HUnit assertions as QuickCheck properties.
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.QuickCheck.IO
hidden-modules: Paths_quickcheck_io
abi: 78f53cb73837b671791d48c1d4720291
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-io-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/quickcheck-io-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/quickcheck-io-0.2.0
hs-libraries: HSquickcheck-io-0.2.0-1Jyoobgydpi1ixfo6rI3UE
depends:
    QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX
    HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3 base-4.10.0.0
abi-depends: QuickCheck-2.10.1-KIwpOgIMAPpCfx99HppzCX=698e905b23be91d72fd87efbe66c208e
             HUnit-1.6.0.0-32Hmh42Ovy04fXZEjkNwW3=403e14f0201c382f502c00d4ca640d0c
             base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
haddock-interfaces: /usr/share/doc/haskell-quickcheck-io/html/quickcheck-io.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
